Monastero Santa Rosa Hotel and Spa on the Amalfi Coast - Cool Hunting
Description: A former convent converted into a lavish 20-room resort, this Italian sanctuary is blessed with heavenly views
Keywords: Hotels,Italy,Spas,Travel,Amalfi Coast,Historic,Pools,Resorts

Cool Hunting Video: Icon Derelict
All Articles
2014 It's Nice That Annual
Cool Hunting Video: Icon Derelict
All Articles
2014 It's Nice That Annual
TRAVEL
Monastero Santa Rosa Hotel and Spa on the Amalfi Coast
A former convent converted into a lavish 20-room resort, this Italian sanctuary is blessed with heavenly views
by CH Contributor
on 04 December 2014
HOTELS ITALY SPAS TRAVEL AMALFI COAST HISTORIC POOLS RESORTS

by Kelly Phillips Badal

Vacationing in a former convent may sound a bit austere—that is, until you experience Monastero Santa Rosa on Italy’s famous Amalfi Coast. This monastery-turned-hotel offers all the peaceful seclusion the sisters enjoyed, with none of the personal sacrifices. And though the popular coastline is studded with hotels, this distinctive destination—with its unmatched combination of five-star luxuries, natural beauty and centuries of character—is a serious standout.

Getting there might have you pressing your palms together in supplication. The main route through the craggy Amalfi coastline is Strada Statale 163—also known as "the road of 1,000 bends." The ancient Roman-built drive is full of hairpin twists and turns, careening over steep precipices past sun-bleached villages and lemon groves for 50 miles, and is just barely wide enough for two cars to pass at some points. About 18 miles in sits Monastero Santa Rosa, perched on a cliff above the small fishing village of Conca dei Marini. The venue's American owner Bianca Sharma spotted the nunnery’s ruins from a boat in 1999 and promptly bought the property. After a lengthy decade-long restoration, it opened as a luxury hotel for the 2012 season.

Much of the convent’s original 17th century architecture remains intact, thanks to Sharma’s careful conservation. Inside, reconfigured spaces pay thoughtful homage to the hotel’s heritage. Nuns' quarters are cleverly combined into 20 unique rooms, some with private terraces or multiple levels. One of the largest is located in what was the sisters’ refectory. All feature fine Italian linens, an array of tasteful period furniture, and deep soaking tubs made from fine Jerusalem stone, in addition to everyday contemporary amenities like minibars, television, and WiFi. Some of the rooms have vaulted ceilings, private alfresco dining areas, and seafront balconies; others have housed famous names like Prince Albert and Princess Charlene of Monaco. The guest rooms exude comfort, and every conceivable wish is quickly taken care of by the attentive staff.

The tasteful restoration continues into Monastero Santa Rosa’s massive 750-foot state-of-the-art spa. Cavernous treatment rooms are carved from spaces once devoted to silent prayers, while the spa’s centerpiece, a vaulted tepidarium (warm relaxation room), is where the sisters made wine. There’s also a sauna, steam room, hydrotherapy pool, whirlpool footbaths, ice fountain and even programmable showers.

The real star of Monastero Santa Rosa is the knockout coastal view, and there’s a countless number of magical places for taking it in. From the convent’s highest point, an airy sunset terrace, guests can gaze as far as the buzzy nearby towns of Amalfi or Positano. There’s the cascade of tiered, expertly manicured semi-tropical gardens, beset with ocean-facing sun loungers, daybeds and cabanas. There’s the breezy dining terrace of the hotel Ristorante, where guests can enjoy the scenery while tasting exclusively sourced extra virgin olive oil produced right in Conca dei Marini. The most breathtaking spot is floating within the curved cliff’s edge infinity pool while surveying the Gulf of Salerno some 660-feet below.

After whiling away the hours on these sacred grounds, be sure to unburden your soul at the large antique wooden confessional resting in the main hallway. It cheekily invites guests “make a confession” by way of a written feedback for the hotel.

Monastero Santa Rosa is located in the town of Conca dei Marini on Italy’s Amalfi Coast. Nightly room and suite rates range from $500 to $2,400. The resort will open for the 2015 season on 17 April.

See more photos in the gallery, images by Tanveer Badal

HOTELS ITALY SPAS TRAVEL AMALFI COAST HISTORIC POOLS RESORTS
TRAVEL
A Week at Whistler: Resort Highlights
Four tips on where to eat, sleep and get pampered in North America's largest mountain resort
by Josh Rubin
Recently spending a week at Whistler Blackcomb (my annual snowboarding destination), I stuck to some of my favorite gear and places but also used the trip as an opportunity to try some new things. This first story, in a series of three, focuses on...
TRAVEL
Jetsetter x Cool Hunting Miami Sweepstakes Deadline
Our curated getaway to Miami ends tomorrow!
by Evan Orensten
The CH-curated Miami getaway ends soon! This all-expenses-paid trip, created with Jetsetter, includes private museum tours, and three nights at the Viceroy Hotel. To enter, visit Jetsetter and sign up for their emails announcing exclusive travel...
TRAVEL
CH x Jetsetter: Miami Getaway Sweepstakes
Win a trip to Miami curated by Cool Hunting!
by Evan Orensten
We love Miami and joined forces with Jetsetter to provide a lucky reader (and guest) with the opportunity to experience it in style&#8212;with visits to galleries and museums, checking out great shops, and eating at some of our favorite restaurants...
TRAVEL
Amangiri
Aman Resorts' alien escape in the Utah desert
by Josh Rubin
Forget interstellar travel&#8212;there's a transcendent resort currently taking bookings here on earth, and it's called Amangiri. Located just over the Arizona border in Canyon Point, UT, the hotel sprawls amongst imposing bluffs with sweeping...
TRAVEL
Wilderness Meets Luxury at Montana's Paws Up
Perfect for outdoor rookies, this family ranch-turned-resort offers up adventure with deluxe facilities
by Adrienne So
Located on 37,000 acres of a breathtakingly beautiful mountain valley outside of Missoula, Montana, the Resort at Paws Up combines rough-and-tumble Western attractions like whitewater rafting, rappelling and hiking with luxurious comfort. The aesthetic...
TRAVEL
Pedras Salgadas Spa & Nature Resort, Portugal
Treehouse accommodation and mineral-rich thermal springs at this eco-minded destination
by CH Contributor
by Ross Belfer As much as one can plan ahead, living in the moment is certainly a fulfilling way to travel. After several days spent in Portugal's bustling second city of Porto, we felt in need of a tranquil getaway wherein a calming atmosphere...
TRAVEL
The Royal Mansour
Beauty and decadent service at Marrakech’s palatial property
by Ariston Anderson
Anyone who books a luxury hotel surely wants the service to adhere to the old adage about being treated like a king, but Marrakech's decadent Royal Mansour palace&#8212;originally intended to serve actual nobility&#8212;truly delivers such an...
TRAVEL
Parrot Cay
Private Island luxury, service and relaxation epitomized in Turks and Caicos
by Josh Rubin
Part of the north Caribbean archipelago of the Turks and Caicos, Parrot Cay was once a refuge for a notorious duo of female pirates, Anne Bonny and Mary Reid. Nearly 300 years later, tranquility prevails over the private island, covering 1,000 acres...
TRAVEL
Word of Mouth Florence: Food + Drink
A quick guide to some of the time-honored specialists making the Tuscan capital a must-visit culinary destination
by Karen Day
There's no shortage of tips for Italy's wildly popular Tuscan capital, but with so many tourist offerings pumping through the historic town of Florence, it's easy to end up eating a subpar pizza near the steps of the illustrious Duomo. Venturing into...
TRAVEL
Boscolo Exedra Milano Hotel
by CH Contributor
by Paolo Ferrarini of Future Concept Lab Despite Milan&#39;s de facto world design capital status, the city lacks design hotels. Boscolo Exedra, a new hotel opening very soon, will fill the gap. The former bank, after one year and &euro;150 million...
TRAVEL
Tokyo High Low
We put Amex Platinum to the test in the sky and on the ground in the future's city
by Josh Rubin
When my plans to get from Beijing to Tokyo required a last-minute change, American Express Platinum Travel was able to confirm a seat on a new flight just hours before departure, even though they didn’t handle my original booking. And when I checked...
TRAVEL
Barracuda Yacht Charter by Fatboy Slim
by CH Contributor
by Juliet Kinsman If you thought boutique-hotel chic need be restricted to terra firma, you haven&#39;t heard of what Fatboy Slim (aka Norman Cook) and friends have been up to. Having got his paws on a classic wooden yacht, Cook&#39;s boat-loving...
Load More...
COOL
HUNTING
Cool Hunting Video: Icon Derelict
All Articles
2014 It's Nice That Annual

# No matches for your search

Unfortunately, we don't have any articles that match your search. Try again or explore some of these links:

CATEGORIES
Design Tech Culture Travel Style Food + Drink
FEATURES
Word of Mouth Interviews Studio Visits Off Piste Scene by All Song of the Car Cool Hunting Video
PEOPLE
Artists Illustrators Graphic Designers Product Designers Fashion Designers Architects Scientists Makers Entrepreneurs Inventors
THINGS
Cars Watches Bags Bicycles Motorcycles Cameras Jewelry Gadgets Snacks Websites
TOPICS
Sustainability Collecting Invention
Show All
Show Best Matches
Load More...